# distjob
An intermediary library used to distribute various jobs/tasks between several machines - receiving job description through API requests - sending them to available workers and allocates the capacity
